@@ -4,12 +4,11 @@ from __future__ import absolute_import
 
 # import apis into api package
 from stackl_client.api.about_api import AboutApi
-from stackl_client.api.configurator_api import ConfiguratorApi
-from stackl_client.api.documents_api import DocumentsApi
 from stackl_client.api.functional_requirements_api import FunctionalRequirementsApi
-from stackl_client.api.policy_agent_api import PolicyAgentApi
+from stackl_client.api.infrastructure_base_api import InfrastructureBaseApi
 from stackl_client.api.policy_templates_api import PolicyTemplatesApi
 from stackl_client.api.services_api import ServicesApi
+from stackl_client.api.snapshots_api import SnapshotsApi
 from stackl_client.api.stack_application_templates_api import StackApplicationTemplatesApi
 from stackl_client.api.stack_infrastructure_templates_api import StackInfrastructureTemplatesApi
 from stackl_client.api.stack_instances_api import StackInstancesApi
